/***************************************************************************
                          confman.cpp  -  description
                             -------------------
    begin                : Sat Mar 22 2003
    copyright            : (C) 2003 by yuval
    email                : yyyme@walla.co.il
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "confman.h"
#include "manager.h"
#include "signalman.h"

#include "confdialog.h"
#include "errorcarrier.h"

#include <kglobalaccel.h>
#include <klocale.h>
#include <kconfig.h>


/* constructor */
ConfMan::ConfMan(){
  /*get a globalaccel - this gives us the abilty to have short-cut keys,
   global mean that they will activate this program method,even when they are click in another application.*/
m_globalKeys= new KGlobalAccel (this);
/*nully the sgiman , we dont need it now.*/
m_SigMan=0;

if(m_globalKeys==0)/*check that we have memory.*/
 throw ErrorCarrier(ErrorCarrier::NO_MEM,"Not enough memory to create globalAccel object.");


}
ConfMan::~ConfMan(){
  if (m_globalKeys!=0)
    delete m_globalKeys;
  if (m_SigMan!=0)
    delete m_SigMan;
  m_SigMan=0;
  m_globalKeys=0;
}

/*only  call this method(LoadConfigs) once!*/

void ConfMan::LoadConfigs(Manager *mng)
{
  /*insert an action that does not require sigman*/
 m_globalKeys->insert( "Switch Text", i18n("Does the Action selected in the menu."),
   i18n("This action allows you to do a selected action on the text in the clipboard "
        "and return it there."),
   CTRL+ALT+Key_S/*this is the short cut key,if u want, it can be changed to even Key_F10*/,
   KShortcut::null(),
 mng, SLOT( PerformDefaultAction() ) );

  m_SigMan=new SignalMan(mng);/*sigman acctually foward signals, since manager methods, require arugrments, while the signals are sent with no arguments at all.*/
 if(m_SigMan!=0)/*if we have no sigman, doesnt matter.. keep working*/
 {
 m_globalKeys->insert( "Auto switch", i18n("Preforms auto switch."),
   i18n("Switches english letter to hebrew, and hebrew to english."),
   KShortcut::null(),
   KShortcut::null(),
 m_SigMan, SLOT( DoManagerAuto() ) );

 m_globalKeys->insert( "Heb switch", i18n("Preforms hebrew switch."),
   i18n("Switches hebrew letter to english ones only."),
   KShortcut::null(),
   KShortcut::null(),
 m_SigMan, SLOT( DoManagerHeb() ) );
  m_globalKeys->insert( "Eng switch", i18n("Preforms english switch."),
   i18n("Switches english letter to hebrew ones only."),
   KShortcut::null(),
   KShortcut::null(),
 m_SigMan, SLOT( DoManagerEng() ) );
  m_globalKeys->insert( "Rev switch", i18n("Reverses hebrew."),
   i18n("Reverses the order of hebrew letters."),
   KShortcut::null(),
   KShortcut::null(),
 m_SigMan, SLOT( DoManagerRev() ) );
  m_globalKeys->insert( "Unicode switch", i18n("Preforms 8bit->unicode switch."),
   i18n("Switches hebrew letters from 8bit representation to unicode."),
   KShortcut::null(),
   KShortcut::null(),
 m_SigMan, SLOT( DoManagerUnicode() ) );
 
  m_globalKeys->insert( "Toggle Paste", i18n("Toogle Paste."),
   i18n("Toogles Paste action in the menu."),
   KShortcut::null(),
   KShortcut::null(),
 m_SigMan, SLOT( ToogleManagerPaste() ) );

  }
 /*this useful KDE function read configuration,that were written, KDE handles that,
 so it really reliving :)
 */
 m_globalKeys->readSettings();
 /*update connects, without it, the keys wont work*/
 m_globalKeys->updateConnections();

        /*read and set them*/
       KConfig *conf=KGlobal::config();
       if(conf!=0)
       {
      QString action;
      conf->setGroup("ACTIONS");
      int temp=conf->readNumEntry(QString("ActionType"));
      if (temp>=0)
        mng->setDefaultAction((Manager::SwitchTypes)temp);
      bool temp2=conf->readBoolEntry(QString( "Paste"));
      mng->setDefaultPaste(temp2);
     }
    
}

void ConfMan::SaveConfigs(const Manager *mng)
{
/*save configurations.*/
  m_globalKeys->writeSettings();
   /*save conf: (menu state)*/
  KConfig *conf=KGlobal::config();
  if( conf!=0)
  {
    QString action;
    conf->setGroup("ACTIONS");
    conf->writeEntry(QString("ActionType"),mng->getDefaultAction());
    conf->writeEntry(QString( "Paste"),mng->getDefaultPaste());
    conf->sync();
  }
  
}

void ConfMan::DisplayConf()
{
  /*call some GUI to handle configurations*/

  /*conf widfet*/
ConfDialog *c= new ConfDialog(m_globalKeys);
if (c->exec()==QDialog::Accepted)
 {
  c->commitChanges();/*put changes in globalKeys*/
  m_globalKeys->updateConnections();
  /*write settings*/
  m_globalKeys->writeSettings();
 }
}

